<h1 align="center">
    <a href="https://www.zelthy.com/"> 
    <img src="https://yt3.googleusercontent.com/e1HArJ9U7Pj8MIf2MKGYW_6GGqdvwUTucgR6gs5u7LaBvAIfZT1INRASf0fOMC7ISVTDYqMPXw=s176-c-k-c0x00ffffff-no-rj" alt="ZCore" width="80px">
    </a>
</h1>


[Website](https://www.zelthy.com/framework) • [Getting Started](https://docs.zelthy.com/docs/category/getting-started) • [Docs](https://docs.zelthy.com/)


[![PyPI version](https://badge.fury.io/py/zelthy3.svg)](https://badge.fury.io/py/zelthy3)
![docs](https://img.shields.io/github/actions/workflow/status/Healthlane-Technologies/zelthy3/docs.yml?branch=main)
[![License](https://img.shields.io/badge/License-Apache_2.0-blue.svg)](https://opensource.org/licenses/Apache-2.0)


## ZCore is an open source multi-tenant Django framework for building enterprise apps

- Quickly build enterprise ready apps, leveraging the power of Django and ZCore package ecosystem
- Host multiple apps on a single deployment with complete isolation - Each app can have its own data models and workflows 
- Built-in user management and user roles
- Rich ecosystem of packages - Leverage the free packages to develop most of your app workflows. 
- Granular policy and permission framework linking user roles with views and models
- Open-core with all  non-enterprise features under the  Apache License allowing commercial and private use.


[![Open in Gitpod](https://gitpod.io/button/open-in-gitpod.svg)](https://gitpod.io/#https://github.com/Healthlane-Technologies/zelthy3-gitpod-sandbox-official/)

![ZCore High Level Architecture](https://docs.zelthy.com/assets/images/Architecture_Diagram-e6eb1b24fca0554edca1110a7de26449.png)

#### App Panel - Central hub to manage all your apps
Perform tasks such as configuring permissions, managing user roles, and much more. 

![ZCore App Panel](https://github.com/Healthlane-Technologies/zelthy3/assets/22682748/b593a821-ec1d-4082-a590-e5ed52cb0c28)

#### Drastically reduce your per app cost through ZCore’s multi-tenant approach:

ZCore redefines multi-tenancy by enabling multiple different apps to run on a single server. Say goodbye to the limitations of traditional scaling methods. With our platform, you can run multiple different applications on a single server, which helps in keeping the cost in check.

![ZCore Scaling](https://zelthy-initium-production-static.s3.amazonaws.com/static/zelthymain/react-images/cost-effective-scaling.svg)


#### Getting Started:
- [Docker](https://docs.zelthy.com/docs/documentation/getting-started/installing-zelthy/docker)
- [Manual](https://docs.zelthy.com/docs/documentation/getting-started/installing-zelthy/manual)
- [Gitpod](https://docs.zelthy.com/docs/documentation/getting-started/installing-zelthy/gitpod)

#### Free Packages
A few essential packages are freely available. These packages enable development of a wide variety of applications and are available for installation from the App Panel.  
- [Login](https://docs.zelthy.com/login)
- [Frames](https://docs.zelthy.com/frame)
- [CRUD](https://docs.zelthy.com/crud)
- [Workflow](https://docs.zelthy.com/workflow)


#### Contributing:
You can contribute to ZCore in many ways, including:
- Leave your star in this repo.
- Share with your colleagues and friends
- Share your suggestions on our slack channel
- Create issues if you find something not working as expected or if you have suggestions on enhancements.
- Provide pull requests for any open issues


#### Official Documentation: https://docs.zelthy.com/




